#!/usr/bin/env python3

import os
import sys
from warnings import warn
from setuptools import setup, find_packages

here = os.path.abspath(os.path.dirname(__file__))


# --------------------------------------------------------------------------- #

# Warn if Using Unsupported Python Version. Currently only support Python 3.5+


if (sys.version_info[0] < 3 or
        (sys.version_info[0] == 3 and sys.version_info[1] < 5)):
    warn("Unsupported Version of Python Detected. Use at your Own Risk.")


# --------------------------------------------------------------------------- #

# Package Info

NAME = 'poseur'
VERSION = "0.1.0"
DESCRIPTION = ' Python 3 Bi-directional RPC Framework using ZeroMQ and Asyncio'
LONG_DESCRIPTION = None
try:
    LONG_DESCRIPTION = open('README.rst').read()
except:
    pass


# --------------------------------------------------------------------------- #


setup(
    name=NAME,
    version=VERSION,
    description=DESCRIPTION,
    long_description=LONG_DESCRIPTION,
    author='Matthew Ellison',
    author_email='matt@arroyonetworks.com',
    maintainer='Matthew Ellison',
    maintainer_email='matt@arroyonetworks.com',
    url='https://github.com/ArroyoNetworks/poseur',
    download_url='https://github.com/ArroyoNetworks/poseur/archive/v0.1.0.tar.gz',
    packages=find_packages(
        exclude=["*.tests", "*.tests.*", "tests.*", "tests"]
    ),
    include_package_data=True,
    license='MIT',
    platforms=['any'],
    install_requires=[
        'pyzmq>=15.2',
    ],
    extras_require={
        "msgpack": ["msgpack-python",]
    },
    tests_require=[
        'pytest',
        'pytest-asyncio',
        'pytest-cov'
    ],
    keywords=['rpc', 'bidirectional', 'async', 'asyncio'],
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 3 :: Only',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: Implementation :: CPython',
    ]
)
